# -*- coding: utf-8 -*-
"""
Created on Mon Sep 27 09:47:13 2021

@author: kevin
"""


import qcodes as qc
from time import sleep, localtime
import numpy as np
import math
import datetime
import pandas as pd
import matplotlib.pyplot as plt
from scipy.signal import savgol_filter
from scipy import interpolate
from scipy.optimize import curve_fit
import os

#Changes Working Directory to File Directory
abspath = os.path.abspath(__file__)
dname = os.path.dirname(abspath)
os.chdir(dname)

def splitsweep(array):
    if len(array)%2 == 0:
        return array[:int(len(array)/2)], array[int(len(array)/2):]
    else:
        print('Array Length is odd !')
        
def splitsweep2(array):
    return array[:,:int(array.shape[1]/2)], array[:,int(array.shape[1]/2)]
    

plt.rcParams.update({'font.size': 32})
plt.rc('lines',linewidth=1.5,linestyle='-')
plt.rcParams['figure.figsize'] = (15,15)
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['xtick.top'] = 'True'
plt.rcParams['ytick.right'] = 'True'
plt.rcParams['axes.linewidth'] = '3'
plt.rcParams['xtick.major.size'] = '15'
plt.rcParams['xtick.major.width'] = '3'
plt.rcParams['ytick.major.size'] = '15'
plt.rcParams['ytick.major.width'] = '3'
plt.rcParams['xtick.major.pad'] = '15'
plt.rcParams['ytick.major.pad'] = '15'
qc.config["core"]["db_location"] = "C:/Users/kevin/Desktop/Desktop Files 2/Transport/VTI_M13_563R/experimentsV4_5.db"
#qc.config["core"]["db_location"] = "C:/Users/kevin/Desktop/Transport/VTI_M13_563/2021_08_16/experimentsV2_23.db"
#qc.config["core"]["db_location"] = "C:/Users/kevin/Desktop/Transport/VTI_M13_563R/experimentsV4_5.db"

######################################################

#id1 = 542
#id2 = 542
#IDs = np.linspace(id1,id2,id2-id1+1).astype(int)

IDs = np.array([542])                  #for Tsweep
#IDs = np.array([483])                  #for Bsweep
#IDs = np.array([538,539])               #for Bsweep also both directions


AC_Conversion = 0.1
Lock_Amp = 0.1
T_Lock = 1.5
######################################################

X_lock = list()
B = list()
GainA = list()
I = list()
Rdiff = list()
GateV = list()
I_sample = list()
U = list()
T = list()
TopgateV = list()
Phase = list()

Count = 0
for i in IDs:
    print(i)
    print(Count)
    qc_data_obj = qc.load_by_id(i)
    df = qc_data_obj.to_pandas_dataframe_dict()
    #time[Count] = np.array(df['time']['time'])
    X_lock.append(np.array(df['X_lock']['X_lock']))
    Phase.append(np.array(df['Phase_lock']['Phase_lock']))
    GateV.append(np.array(df['GateV']['GateV']))
    U.append(np.array(df['U']['U']))
    I.append(np.array(df['I']['I']))
    GainA.append(np.array(df['GainA']['GainA']))
    B.append(np.array(df['B']['B']))
    T.append(np.array(df['T']['T']))
    #TopgateV.append(np.array(df['TopgateV']['TopgateV']))
    Rdiff.append(np.array(abs(X_lock[Count]/GainA[Count]/I[Count]/Lock_Amp/AC_Conversion)))
    Count+=1

I_sample = np.multiply(GateV,I)
U_sample = np.divide(U,GainA)  
IAC = Lock_Amp*AC_Conversion*I[0][0]
U_AC = np.divide(X_lock,GainA)
T_real = np.array([1.5,1.6,2.2,2.6,3.3,4.8,6.5,9.9])
#%%
m = len(IDs)
for i in range (m):
    df = pd.DataFrame({"U_AC(V)" : U_AC[i], "I_AC(A)" : IAC, "Phase_U_AC(deg)" : Phase[i], "f_AC(Hz)" : 31.7, "T_integration_Lock(s)" : 1.5, "B(T)" : B[i],"T(K)" : T[i]})
    df.to_csv("Rawdata_Nb_T.csv", index=False)
#%% Export Temperaturkalibration
T_set = np.array([1.46,1.6,1.8,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5,7,7.5,8,8.5,9,9.5,10,10.5,11,11.5,12,12.5,13,14,15,16,18,20])  
T_sensor = np.array([1.49,1.55,1.58,1.60,1.67,2.16,2.39,2.59,2.97,3.32,3.64,4.12,4.47,4.77,5.21,5.49,6.09,6.54,6.85,7.43,8.00,8.32,8.72,9.04,9.44,9.93,10.97,11.91,12.78,14.39,16.11])
for i in range (1):
    df = pd.DataFrame({"T_set(K)" : T_set, "T_sensor(K)" : T_sensor})
    df.to_csv("Rawdata_T_recalibration.csv", index=False)
    
#%% Plot Tsweep ID: 542
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

plt.plot(splitsweep(T[0])[0], splitsweep(Rdiff[0])[0], 'b', linewidth = 2, label = '$\\rightarrow$')
plt.plot(splitsweep(T[0])[1], splitsweep(Rdiff[0])[1], 'r', linewidth = 2, label = '$\\leftarrow$')

    
plt.title('ID:' + str(IDs[0]) + ' T-raw' + ' $I_{AC}= $' + str(int(round(IAC/1e-9))) + 'nA, $T_{Lock}$ = ' + str(T_Lock) + 's')
plt.xlabel('$T$ (K)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.xticks([2.8,5.9,8.5,10.5,13,15.1]) # correspond to T_sensor = 2,4,6,8,10,12
plt.yticks([268,272,276,280,284,288])
plt.axvline(9.90,color ='black')
plt.axvline(9.595,color ='black')
plt.axvline(9.29,color ='black')
plt.axhline(270.6,color ='black')
plt.axhline(278.55,color ='black')
plt.axhline(286.5,color ='black')
plt.legend()
plt.savefig('Supp_Nb_Tc_' + str(IDs[0]) + '_' + '.png')
plt.savefig('Supp_Nb_Tc_' + str(IDs[0]) + '_' + '.pdf')

print('Supp_Nb_Tc_' + str(IDs[0]) + '.pdf' '  saved')

#%% Plot Bsweep ID:483
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(B[i], Rdiff[i], 'b', linewidth = 2, label = '$\\rightarrow$')

plt.title('ID:' + str(IDs[0]) + ' $I_{AC}= $' + str(int(round(IAC/1e-9))) + 'nA, $T_{Lock}$ = ' + str(T_Lock) + 's')
plt.xlabel('$B$ (T)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.yticks([268,272,276,280,284])

plt.axvline(3.4942,color ='black')
plt.axhline(267.66,color ='black')
plt.axhline(283.88,color ='black')
plt.axhline(275.77,color ='black')
plt.legend()
plt.savefig('Supp_Nb_Bc_' + str(IDs[0]) + '_' + '.png')
plt.savefig('Supp_Nb_Bc_' + str(IDs[0]) + '_' + '.pdf')

print('Supp_Nb_Bc_' + str(IDs[0]) + '.pdf' '  saved')


#%% Plot Bsweep IDs: 538,539
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

plt.plot(B[0], Rdiff[0], 'b', linewidth = 2, label = '$\\rightarrow$')
plt.plot(B[1], Rdiff[1], 'r', linewidth = 2, label = '$\\leftarrow$')

plt.title('ID:' + str(IDs[0]) + ' $I_{AC}= $' + str(int(round(IAC/1e-9))) + 'nA, $T_{Lock}$ = ' + str(T_Lock) + 's')
plt.xlabel('$B$ (T)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.xlim(2.8,4.0)
plt.ylim(1600,2000)
plt.axvline(3.4944,color ='black')
plt.axvline(3.3550,color ='black')
plt.axvline(3.425,color ='black')
plt.axhline(1984,color ='black')
plt.axhline(1796,color ='black')
plt.axhline(1608,color ='black')
plt.legend()
plt.savefig('Supp_Interface_Bc_' + str(IDs[0]) + '_' + '.png')
plt.savefig('Supp_Interface_Bc_' + str(IDs[0]) + '_' + '.pdf')

print('Supp_Interface_Bc_' + str(IDs[0]) + '.pdf' '  saved')

#%% Plot Bsweep Waterfall
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(B[i], Rdiff[i]+25*i, label = 'IDC='+str('%.2f'%GateV[i][0])+'$\mu A$')

plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) +'| Bsweep Water | IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$B$ (T)')
plt.ylabel('$R_{Diff}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'Water.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'Water.pdf')

#%% Plot IDs = np.array([557,558,559,560,561])
plt.plot(I_sample[0]*1e6, Rdiff[0],'-r')
plt.plot(I_sample[1]*1e6, Rdiff[1],'-g')
plt.plot(I_sample[2]*1e6, Rdiff[2],'-b')
plt.plot(I_sample[3]*1e6, Rdiff[3],'-k')
plt.plot(I_sample[4]*1e6, Rdiff[4],'-y')
plt.title('ID:' + str(IDs[0]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.savefig(str(IDs[0]) + '-' + str(IDs[-1]) + 'I'+'.png')
#plt.savefig(str(IDs[0]) + '-' + str(IDs[-1]) + 'I'+'.pdf')


#%% Plot DiffIV B-Batch
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(U_sample[i]*1e3)[0],splitsweep(Rdiff[i])[0],label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$U_{sample}$ (mV)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'.pdf')

#%% Plot DiffIV B-Batch I
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[0],splitsweep(Rdiff[i])[0],label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.pdf')

#%% Plot DiffIV B-Batch Waterfall
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(U_sample[i]*1e3)[0],splitsweep(Rdiff[i]+15*i)[0],label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| Waterfall IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$U_{sample}$ (mV)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'Water.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'Water.pdf')

#%% Plot DiffIV B-Batch Waterfall I
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[1],splitsweep(Rdiff[i]+25*i)[1],label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| Waterfall IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'WaterI+-.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'WaterI+-.pdf')

#%% Plot DiffIV B-Batch I normaleized (309 for 100nm ribbon 563R)(300nm ; 305/0; 307/1 )
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[0],(splitsweep(Rdiff[i])[0]/splitsweep(Rdiff[i])[0][306]),label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U|0 IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Inorm' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Inorm' +'.pdf')

#%% Plot DiffIV B-Batch I Single 
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(I_sample[i]*1e6,Rdiff[i],label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.pdf')

#%% Plot DiffIV T-Batch
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(U_sample[i]*1e3)[0],splitsweep(Rdiff[i])[0],label = 'T='+str('%.2f'%T[i][0])+'K')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$U_{sample}$ (mV)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+'.pdf')

#%% Plot DiffIV T-Batch I
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[0],splitsweep(Rdiff[i])[0],label = 'T='+str('%.2f'%T[i][0])+'K')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.pdf')

#%% Plot DiffIV T-Batch I Waterfall
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[1],splitsweep(Rdiff[i]+25*i)[1],label = 'T='+str('%.2f'%T[i][0])+'K')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'WaterI' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'WaterI' +'.pdf')
#%% Plot DiffIV Gate-Batch I
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[0],splitsweep(Rdiff[i])[0],label = 'TG='+str('%.2f'%TopgateV[i][0])+'V')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U|0 IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Idirection0' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Idirection0' +'.pdf')
#%% Plot DiffIV Gate-Batch I normaleized (309 for 100nm ribbon 563R)(300nm ; 305/0; 307/1 )
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(splitsweep(I_sample[i]*1e6)[0],(splitsweep(Rdiff[i])[0]/splitsweep(Rdiff[i])[0][305]),label = 'TG='+str('%.2f'%TopgateV[i][0])+'V')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '519-535|+U->-U|0 IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
#plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Inorm5195350' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'Inorm5195350' +'.pdf')

#%% Plot DiffIV T-Batch I Single
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

for i in range(n):
    plt.plot(I_sample[i]*1e6,Rdiff[i],label = 'T='+str('%.2f'%T[i][0])+'K')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(IAC/1e-9)) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.png')
plt.savefig(str(IDs[0]) + '-' + str(IDs[-1])+ 'I' +'.pdf')

#%% Plot DiffHall
def Hallfunc(x,a,b):
    return a*x + b

Ix = 100*10**-9
d = 20*10**-9 #thickness
popt, pcov = curve_fit(Hallfunc,B[0], X_lock[0]/GainA[0][0]*1000000)
n2D = Ix/(1.602*10**-19*popt[0]*10**-6)/10**4      # last factor conversion to cm-2
n3D = Ix/(1.602*10**-19*popt[0]*10**-6)/d/10**6    # last factor conversion to cm-3
#plt.plot(B[0], popt[0]*B[0]+popt[1])
plt.plot(B[0], Hallfunc(B[0],popt[0],popt[1]),'-r', linewidth=5)
plt.plot(B[0],X_lock[0]/GainA[0][0]*1000000,'.k')
plt.title('ID:' + str(IDs[0]) +'| Hall | IAC = 100nA, T = 3s')
plt.xlabel('$B$ (T)')
plt.ylabel('$U_{Hall}$($\mu V$)')
plt.savefig(str(IDs[0])+'.png')
plt.savefig(str(IDs[0]) +'.pdf')
print ('n2D= ' + str(f"{n2D:.2e}") +' cm^-2')
print ('n3D= ' + str(f"{n3D:.2e}") +' cm^-3')
#%% Colormap B 
Rdiff = np.array(Rdiff)
#na, nb = (10, 1000)  
a = np.array(B)[:,1]  
b = np.linspace(5, 0, 1200)  
xa, xb = np.meshgrid(a, b)
Angles = xa.T
#Anglesx = np.linspace(90,40,6)
#Anglesy = np.linspace(90,40,1000)
plt.pcolor(splitsweep2(I_sample*1e6)[0],splitsweep2(Angles)[0],splitsweep2(Rdiff)[0],cmap='hot')
#plt.imshow(Rdiff,extent=(0, 1000, 0, 1000),cmap='jet')
plt.colorbar(label = 'Rdiff (Ohm)')
#plt.xlim(400,600)
#plt.clim(1700,1500)
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('I_sample (uA)')
plt.ylabel('B-Field(T)')
#plt.xlim(-10,10)
plt.savefig('Heatmap' + str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.png')
plt.savefig('Heatmap' + str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.pdf')

#%% Colormap T 
Rdiff = np.array(Rdiff)
#na, nb = (10, 1000)  
a = np.array(T)[:,1]  
b = np.linspace(5, 0, 1200)  
xa, xb = np.meshgrid(a, b)
Angles = xa.T
#Anglesx = np.linspace(90,40,6)
#Anglesy = np.linspace(90,40,1000)
plt.pcolor(splitsweep2(I_sample*1e6)[0],splitsweep2(Angles)[0],splitsweep2(Rdiff)[0],cmap='hot')
#plt.imshow(Rdiff,extent=(0, 1000, 0, 1000),cmap='jet')
plt.colorbar(label = 'Rdiff (Ohm)')
#plt.xlim(400,600)
#plt.clim(5400,5800)
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('I_sample (uA)')
plt.ylabel('T(K)')
#plt.xlim(-10,10)
plt.savefig('Heatmap' + str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.png')
plt.savefig('Heatmap' + str(IDs[0]) + '-' + str(IDs[-1])+ 'I'+'.pdf')


#%% Plot DiffIV B-Batch I Mean Plot
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)
l = int(np.size(I_sample)/2)

Rdifftest1 = np.zeros((n,l))
Rdifftest2 = np.zeros((n,l))
Itest2 = np.zeros((n,l))
shift1 = np.zeros(n,dtype=int)
shift2 = np.zeros(n,dtype=int)
shiftsum = np.zeros(n,dtype=int)
Itest_cut = np.zeros((n,l))
Rdifftest1_cut = np.zeros((n,l))
Rdifftest2_cut = np.zeros((n,l))
Rdiffmean = np.zeros((n,l))

for i in range(n):
    Rdifftest1[i] = np.flipud(splitsweep(Rdiff[i])[0])
    Rdifftest2[i] = splitsweep(Rdiff[0])[1]
    Itest2[i] = splitsweep(I_sample[i]*1e6)[1]
    shift1[i] = int(abs(np.where(Rdifftest1[i] == np.amin(Rdifftest1[i]))[0][0]-299))
    shift2[i] = int(abs(np.where(Rdifftest2[i] == np.amin(Rdifftest2[i]))[0][0]-299))
    shiftsum[i] = shift1[i]+shift2[i]
    Itest_cut[i] = Itest2[i][shift1[i]:-shift2[i]]
    Rdifftest1_cut[i] = Rdifftest1[i][:-shiftsum[i]]
    Rdifftest2_cut[i] = Rdifftest2[i][shiftsum[i]:]
    Rdiffmean[i] = (Rdifftest1_cut[i]+Rdifftest2_cut[i])/2
    plt.plot(Itest_cut[i],Rdiffmean[i],color = 'k',label = 'B='+str('%.2f'%B[i][0])+'T')
    
#plt.plot(Itest_cut,Rdifftest1_cut,color = 'r',label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(Itest_cut,Rdifftest2_cut,label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(Itest_cut,Rdiffmean,color = 'k',label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()

#%% Plot DiffIV B-Batch I Mean Plot Test
n=len(IDs)
colors=plt.cm.jet(np.linspace(0,1,n))
plt.rcParams['axes.prop_cycle'] = plt.cycler(color = colors)

Rdifftest1 = np.flipud(splitsweep(Rdiff[0])[0])
Rdifftest2 = splitsweep(Rdiff[0])[1]
#Itest1 = splitsweep(I_sample[0]*1e6)[0]
Itest2 = splitsweep(I_sample[0]*1e6)[1]

shift1 = abs(np.where(Rdifftest1 == np.amin(Rdifftest1))[0][0]-299)
shift2 = abs(np.where(Rdifftest2 == np.amin(Rdifftest2))[0][0]-299)
shiftsum = shift1+shift2
#dshift = np.int(np.round(np.abs(shift1-shift2)/2))
Itest_cut = Itest2[shift1:-shift2]
Rdifftest1_cut = Rdifftest1[:-shiftsum]
Rdifftest2_cut = Rdifftest2[shiftsum:]


Rdiffmean = (Rdifftest1_cut+Rdifftest2_cut)/2
#plt.plot(splitsweep(I_sample[i]*1e6)[0],splitsweep(Rdiff[i])[0],color = 'r',label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(splitsweep(I_sample[i]*1e6)[1],splitsweep(Rdiff[i])[1],label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(splitsweep(Itest2,splitsweep(Rdiff[i])[0],label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(splitsweep(I_sample[i]*1e6)[1],splitsweep(Rdiff[i])[1],label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(splitsweep(I_sample[i]*1e6)[0],splitsweep(Rdiff[i])[0],color = 'r',label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(Itest2,Rdifftest2,label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(Itest2,Rdifftest1,color = 'r',label = 'B='+str('%.2f'%B[i][0])+'T')
#plt.plot(Itest2,Rdifftest2,label = 'B='+str('%.2f'%B[i][0])+'T')
plt.plot(Itest_cut,Rdifftest1_cut,color = 'r',label = 'B='+str('%.2f'%B[i][0])+'T')
plt.plot(Itest_cut,Rdifftest2_cut,label = 'B='+str('%.2f'%B[i][0])+'T')
plt.plot(Itest_cut,Rdiffmean,color = 'k',label = 'B='+str('%.2f'%B[i][0])+'T')
    
plt.title('ID:' + str(IDs[0]) + '-' + str(IDs[-1]) + '|+U->-U| IAC = ' + str(int(round(IAC/1e-9))) + 'nA, T_Lock = ' + str(T_Lock) + 's')
plt.xlabel('$I_{sample}$ ($\mu A$)')
plt.ylabel('$\dfrac{dU}{dI}$($\Omega$)')
plt.legend()



