# -*- coding: utf-8 -*-
"""
Created on Tue Dec 14 16:37:26 2021

@author: kevin
"""


import qcodes as qc
from time import sleep, localtime
import numpy as np
import math
import datetime
import pandas as pd
import matplotlib.pyplot as plt
from scipy.signal import savgol_filter
from scipy import interpolate
from scipy.optimize import curve_fit
import os

#Changes Working Directory to File Directory
abspath = os.path.abspath(__file__)
dname = os.path.dirname(abspath)
os.chdir(dname)

def splitsweep(array):
    if len(array)%2 == 0:
        return array[:int(len(array)/2)], array[int(len(array)/2):]
    else:
        print('Array Length is odd !')
        
def splitsweep2(array):
    return array[:,:int(array.shape[1]/2)], array[:,int(array.shape[1]/2)]
    
def Linfunc(x,a,b):
    return a*x + b

plt.rcParams.update({'font.size': 32})
plt.rc('lines',linewidth=1.5,linestyle='-')
plt.rcParams['figure.figsize'] = (15,15)
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['xtick.top'] = 'True'
plt.rcParams['ytick.right'] = 'True'
plt.rcParams['axes.linewidth'] = '3'
plt.rcParams['xtick.major.size'] = '15'
plt.rcParams['xtick.major.width'] = '3'
plt.rcParams['ytick.major.size'] = '15'
plt.rcParams['ytick.major.width'] = '3'
plt.rcParams['xtick.major.pad'] = '15'
plt.rcParams['ytick.major.pad'] = '15'

#M13 563L Resistance at 0 bias voltage for different devices and distances to the interface

d1 = np.array([271,1122])
d2 = np.array([182,835])
d3 = np.array([185,842])
d4 = np.array([440,1233])
d5 = np.array([202,827])
d6 = np.array([202,827])
d7 = np.array([206,823])
d8 = np.array([206,823])

R1 = np.array([1.764,15.487])
R2 = np.array([0.785,3.294])
R3 = np.array([1.054,4.404])
R4 = np.array([2.47,8.06])
R5 = np.array([1.155,4.228])
R6 = np.array([1.202,4.271])
R7 = np.array([1.334,4.807])
R8 = np.array([1.229,4.698])


plt.scatter(d1/1000, R1,s =100, label = '1')
plt.scatter(d2/1000, R2,s =100, label = '2')
plt.scatter(d3/1000, R3,s =100, label = '3')
plt.scatter(d4/1000, R4,s =100, label = '4')
plt.scatter(d5/1000, R5,s =100, label = '5')
plt.scatter(d6/1000, R6,s =100, label = '6')
plt.scatter(d7/1000, R7,s =100, label = '7')
plt.scatter(d8/1000, R8,s =100, label = '8')
plt.xlabel('$d$ ($\mu$m)')
plt.ylabel('R($k\Omega$)')
plt.legend()


#d = np.array([271,1122,182,835,185,842,440,1233,202,827,202,827,206,823,206,823])
#R = np.array([1.764,15.487,0.785,3.294,1.054,4.404,2.47,8.06,1.155,4.228,1.202,4.271,1.334,4.807,1.229,4.698])
#d = np.array([271,182,835,185,842,440,1233,202,827,202,827,206,823,206,823])
#R = np.array([1.764,0.785,3.294,1.054,4.404,2.47,8.06,1.155,4.228,1.202,4.271,1.334,4.807,1.229,4.698])
d = np.array([271,182,835,185,842,440,202,827,202,827,206,823,206,823])
R = np.array([1.764,0.785,3.294,1.054,4.404,2.47,1.155,4.228,1.202,4.271,1.334,4.807,1.229,4.698])
#d = np.array([271,182,185,440,202,202,206,206])
#R = np.array([1.764,0.785,1.054,2.47,1.155,1.202,1.334,1.229])

x = np.linspace(0,1300,1301)


popt, pcov = curve_fit(Linfunc,d, R)
plt.plot(x/1000, Linfunc(x,popt[0],popt[1]),'-k', linewidth=5, label = 'R = ' + str('%.2f'%(popt[0]*1000)) +'$\, k\Omega / \mu m \cdot$d'+ '+' + str('%.0f'%(popt[1]*1000)) + '$\, \Omega$' )
plt.legend()
plt.title('M13_563L RInt = ' + str('%.0f'%(popt[1]*1000)) + 'Ohm' + ', RhoTI = ' + str('%.2f'%(popt[0]*1000)) + 'kOhm/um')
#print (popt)
print ('Rint= (' + str('%.4f'%popt[1]) + ' +- ' + str('%.5f'%np.sqrt(pcov[1][1])) + ') kOhm')
print ('RhoTI = (' + str('%.4f'%(popt[0]*1000)) + ' +- ' + str('%.5f'%(np.sqrt(pcov[0][0])*1000)) + ') kOhm/um')

#plt.savefig('Supp_Linfit_' + '.png')
#plt.savefig('Supp_Linfit_' + '.pdf')
#%%
for i in range (1):
    df = pd.DataFrame({"Distance(nm)" : d, "Resistance(kOhm)" : R})
    df.to_csv("Rawdata_TI_Linfit.csv", index=False)
    
#%%
deltax = np.linspace(0,50,51)
Rintfit = []

for i in deltax: 
    popt, pcov = curve_fit(Linfunc,d+i, R)
    Rintfit.append(popt[1]*1000)


popt5, pcov5 = curve_fit(Linfunc,deltax, Rintfit)        
plt.figure (2)
title = 'M13_563L Rintfit deltax depenence'
plt.scatter(deltax, Rintfit,s = 100, c = 'r')
plt.plot(deltax, Linfunc(deltax,popt5[0],popt5[1]),'-k', linewidth=5,label = '[1] a= ' + str('%.2f'%(popt5[0])) + 'Ohm/nm')
plt.title('M13_563L RIntfit (deltax) ')
plt.xlabel('$deltax$ (nm)')
plt.ylabel('Rintfit($\Omega$)')
plt.legend()
#plt.savefig(str(title) + '.png')
#plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 437-457
title = 'M13_563R 437-457[1] Peakposition B Field'
B = np.array([0,0.2,0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2.0,2.2,2.4,2.6,2.8,3.0,3.2])
P1 = np.array([-10.4,-10.1,-9.4,-8.5,-5.5,-5.7,-5.3,-4.3,-4.1,-3.3,-2.9,-2.5,-2.1,-1.5,-1.2,-0.8,-0.4])
P2 = np.array([11.7,11.5,10.7,9.4,8.7,7.0,6.6,5.9,5.5,4.7,4.3,3.9,3.8,3.1,2.8,2.2,1.7])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B[4:], P_diff[4:])
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
#plt.savefig(str(title) + '.png')
#plt.savefig(str(title) + '.pdf')
#%% Peak Analysis T [1] 458-465
title = 'M13_563R 458-465[1] Peakposition Temperature'
T = np.array([1.44,2,3,4,5,7,9])
T2 = np.array([1.44,2,3,4,5,7])
PT1 = np.array([-8.3,-7.0,-7.0,-7.0,-7.0,-5.1,-4.3])
PT2 = np.array([9.5,8.1,8.1,8.2,8,7.3,5.4])
PT3 = np.array([-21.6,-18.0,-18.1,-18.0,-17.7,-15.2])
PT4 = np.array([21.7,17.8,18.3,18.3,17.8,15.9])

PT_diff = (PT2-PT1)/2
PT_diff2 = (PT4-PT3)/2

#poptT, pcovT = curve_fit(Linfunc,T[4:], PT_diff[4:])
#plt.plot(T, Linfunc(T,poptT[0],poptT[1]),'-k', linewidth=5)
plt.scatter(T, PT_diff ,color = 'b', s = 100, label = '[1] 1st')
plt.scatter(T2, PT_diff2, color = 'r',s = 100, label = '[1] 2nd')
plt.xlabel('$T$ (K)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 490-510
title = 'M13_563R 490-510[1] Peakposition B Field'
B = np.array([0,0.2,0.4,0.6,0.8,1])
P1 = np.array([-49.6,-44.3,-40.0,-36.6,-31.8,-27.2])
P2 = np.array([52.1,48.3,44.6,40.3,36.6,32.1])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B, P_diff)
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis T [1] 511-518
title = 'M13_563R 511-518[1] Peakposition Temperature'
T = np.array([1.44,2,3,4,5,7])
PT1 = np.array([-49.7,-32.1,-31.8,-31.8,-31.0,-27.6])
PT2 = np.array([51.6,34.8,34.8,35.3,33.8,31.2])


PT_diff = (PT2-PT1)/2


#poptT, pcovT = curve_fit(Linfunc,T[4:], PT_diff[4:])
#plt.plot(T, Linfunc(T,poptT[0],poptT[1]),'-k', linewidth=5)
plt.scatter(T, PT_diff ,color = 'b', s = 100, label = '[1] 1st')
plt.xlabel('$T$ (K)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 25-41 V3
title = 'M13_563L 25-41[1] Peakposition B Field'
B = np.array([0.2,0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2.0,2.2,2.4])
P1 = np.array([-7.7,-7.7,-6.7,-6.2,-5.3,-5.0,-4.3,-3.7,-3.2,-2.7,-2.2,-1.7])
P2 = np.array([9.5,9.3,8.3,7.5,6.9,6.3,5.7,5.0,4.4,3.9,3.4,2.9])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B, P_diff)
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 59-76 V3
title = 'M13_563L 59-76[1] Peakposition B Field'
B = np.array([0,0.2,0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2.0])
P1 = np.array([-8.2,-7.5,-7.2,-6.7,-6.3,-5.9,-5.5,-4.8,-4.2,-3.9,-3.3])
P2 = np.array([8.7,8.2,7.9,7.2,6.9,6.5,5.8,5.6,5.0,4.3,3.6])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B, P_diff)
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 97-113 V3
title = 'M13_563L 97-113[1] Peakposition B Field'
B = np.array([0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2.0,2.2,2.4,2.6])
P1 = np.array([-8.0,-7.1,-6.8,-6.6,-6.1,-5.6,-5.3,-4.4,-3.8,-3.1,-2.6,-1.8])
P2 = np.array([10.4,9.2,8.7,8.3,8.0,7.4,6.8,5.8,5.5,4.7,4.3,3.9])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B, P_diff)
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')

#%% Peak Analysis B [1] 97-113 V3
title = 'M13_563L 97-113[1] Peakposition B Field'
B = np.array([0.4,0.6,0.8,1,1.2,1.4,1.6,1.8,2.0,2.2,2.4,2.6])
P1 = np.array([-8.0,-7.1,-6.8,-6.6,-6.1,-5.6,-5.3,-4.4,-3.8,-3.1,-2.6,-1.8])
P2 = np.array([10.4,9.2,8.7,8.3,8.0,7.4,6.8,5.8,5.5,4.7,4.3,3.9])
P_diff = (P2-P1)/2

popt1, pcov1 = curve_fit(Linfunc,B, P_diff)
plt.plot(B, Linfunc(B,popt1[0],popt1[1]),'-k', linewidth=5)
plt.scatter(B, P_diff ,s = 100, label = '[1] a= ' + str('%.2f'%(popt1[0])) + 'uA/T')
plt.xlabel('$B$ (T)')
plt.ylabel('Peakposition_I(uA)')
plt.title(title)
plt.legend()
plt.savefig(str(title) + '.png')
plt.savefig(str(title) + '.pdf')


